
# Slot: predicate




URI: [biolink:organism_taxon_to_organism_taxon_specialization_predicate](https://w3id.org/biolink/vocab/organism_taxon_to_organism_taxon_specialization_predicate)


## Domain and Range

[OrganismTaxonToOrganismTaxonSpecialization](OrganismTaxonToOrganismTaxonSpecialization.md) &#8594;  <sub>1..1</sub> [PredicateType](types/PredicateType.md)

## Parents

 *  is_a: [predicate](predicate.md)

## Children


## Used by

 * [OrganismTaxonToOrganismTaxonSpecialization](OrganismTaxonToOrganismTaxonSpecialization.md)
